@@ -45,7 +45,7 @@ namespace ksudoku {
 class Game::Private : public GameIFace {
 public:
 	inline Private() : m_refCount(1) { }
-	inline ~Private() {
+	inline ~Private() override {
 		delete puzzle;
 	}
 public:
@@ -61,14 +61,14 @@ public: // The slots of GameIFace
 	void undo2Checkpoint() override;
 	
 public:
-	inline void emitModified(bool isModified) { emit modified(isModified); }
+	inline void emitModified(bool isModified) { Q_EMIT modified(isModified); }
 	inline void emitCompleted(bool isCorrect, const QTime& required, bool withHelp) {
-		emit completed(isCorrect, required, withHelp);
+		Q_EMIT completed(isCorrect, required, withHelp);
 	}
-	inline void emitCellChange(int index) { emit cellChange(index); }
-	inline void emitFullChange() { emit fullChange(); }
+	inline void emitCellChange(int index) { Q_EMIT cellChange(index); }
+	inline void emitFullChange() { Q_EMIT fullChange(); }
 	inline void emitCageChange(int cageNumP1, bool showLabel)
-                                  { emit cageChange(cageNumP1, showLabel); }
+                                  { Q_EMIT cageChange(cageNumP1, showLabel); }
 	
 public:
 	PuzzleState state;
@@ -98,12 +98,12 @@ void Game::Private::undo() {
 	
 	const QVector<int>& indices = event.cellIndices();
 	if(indices.count() > 10) {
-		emit fullChange();
+		Q_EMIT fullChange();
 	} else {
 		for(int i = 0; i < indices.count(); ++i)
-			emit cellChange(indices[i]);
+			Q_EMIT cellChange(indices[i]);
 	}
-	emit modified(true);
+	Q_EMIT modified(true);
 }
 
 void Game::Private::redo() {
@@ -114,12 +114,12 @@ void Game::Private::redo() {
 
 	const QVector<int>& indices = event.cellIndices();
 	if(indices.count() > 10) {
-		emit fullChange();
+		Q_EMIT fullChange();
 	} else {
 		for(int i = 0; i < indices.count(); ++i)
-			emit cellChange(indices[i]);
+			Q_EMIT cellChange(indices[i]);
 	}
-	emit modified(true);
+	Q_EMIT modified(true);
 }
 
 void Game::Private::addCheckpoint() {
@@ -133,12 +133,12 @@ void Game::Private::undo2Checkpoint() {
  */
 
 Game::Game()
-	: m_private(0)
+	: m_private(nullptr)
 {
 }
 
 Game::Game(Puzzle* puzzle)
-	: m_private(0)
+	: m_private(nullptr)
 {
 	if(!puzzle) return;
 
@@ -221,7 +221,7 @@ GameIFace* Game::interface() const {
 }
 
 Puzzle* Game::puzzle() const {
-	if(!m_private) return 0;
+	if(!m_private) return nullptr;
 	return m_private->puzzle;
 }
 
@@ -791,7 +791,7 @@ void Game::setMessageParent(QWidget * messageParent)
 
 QWidget * Game::messageParent()
 {
-	return (m_private ? m_private->m_messageParent : 0);
+	return (m_private ? m_private->m_messageParent : nullptr);
 }
 
 }
