@@ -22,7 +22,6 @@
 
 #include "ksview.h"
 
-#include "ksudokugame.h"
 #include "settings.h"
 
 
@@ -38,11 +37,11 @@
 namespace ksudoku{
 
 KsView::KsView(const Game& game, GameActions* gameActions, QObject* parent)
-	: QObject(parent), m_game(game), m_gameActions(gameActions), m_viewWidget(0)
+	: QObject(parent), m_game(game), m_gameActions(gameActions), m_viewWidget(nullptr)
 {
-	m_symbolTable = 0;
+	m_symbolTable = nullptr;
 	m_currentValue = 1;
-	m_valueListWidget = 0;
+	m_valueListWidget = nullptr;
 }
 
 KsView::~KsView()
@@ -54,17 +53,17 @@ void KsView::createView() {
 	GameType type = m_game.puzzle()->gameType();
 	switch(type) {
 		case TypeSudoku: {
-			setWidget(new View2D(0, m_game, m_gameActions));
+			setWidget(new View2D(nullptr, m_game, m_gameActions));
 			break;
 		}
 		case TypeCustom: {
 #ifdef OPENGL_SUPPORT
 			if(m_game.puzzle()->graph()->sizeZ() > 1) {
 			    // TODO - IDW - Add a parent widget. Memory leak?
-			    setWidget(new RoxdokuView(m_game, m_gameActions, 0));
+			    setWidget(new RoxdokuView(m_game, m_gameActions, nullptr));
 			}
 			else {
-			    setWidget(new View2D(0, m_game, m_gameActions));
+			    setWidget(new View2D(nullptr, m_game, m_gameActions));
 			}
 #else
 			setWidget(new View2D(0, m_game, m_gameActions));
@@ -74,7 +73,7 @@ void KsView::createView() {
 #ifdef OPENGL_SUPPORT
 		case TypeRoxdoku: {
 			// TODO - IDW - Add a parent widget. Memory leak?
-			setWidget(new RoxdokuView(m_game, m_gameActions, 0));
+			setWidget(new RoxdokuView(m_game, m_gameActions, nullptr));
 			break;
 		}
 #endif
@@ -96,7 +95,7 @@ void KsView::createView() {
 void KsView::selectValue(int value) {
 	if(value == m_currentValue) return;
 	m_currentValue = value;
-	emit valueSelected(value);
+	Q_EMIT valueSelected(value);
 }
 
 SymbolTable* KsView::symbolTable() const {
@@ -105,13 +104,13 @@ SymbolTable* KsView::symbolTable() const {
 
 void KsView::setSymbolTable(SymbolTable* table) {
 	m_symbolTable = table;
-	emit symbolsChanged(table);
+	Q_EMIT symbolsChanged(table);
 }
 
 void KsView::setWidget(QWidget* widget) {
 	m_viewWidget = widget;
-	emit flagsChanged(m_flags);
-	emit symbolsChanged(m_symbolTable);
+	Q_EMIT flagsChanged(m_flags);
+	Q_EMIT symbolsChanged(m_symbolTable);
 	
 	m_view = dynamic_cast<ViewInterface*>(widget);
 }
