@@ -153,7 +153,7 @@ void ValueListWidget::setMaxValue(int maxValue) {
 	
 	if(m_selectedValue > m_maxValue) m_selectedValue = 1;
 
-	resizeEvent(0);
+	resizeEvent(nullptr);
 }
 
 void ValueListWidget::resizeEvent(QResizeEvent*)
@@ -177,7 +177,7 @@ void ValueListWidget::selectValue(int value) {
 
 void ValueListWidget::selectValueItem(int value) {
 	selectValue(value);
-	emit valueSelected(value);
+	Q_EMIT valueSelected(value);
 }
 
 void ValueListWidget::wheelEvent (QWheelEvent* e) {
