@@ -40,7 +40,7 @@ class View2DScene : public QGraphicsScene {
 	Q_OBJECT
 public:
 	explicit View2DScene(GameActions* gameActions);
-	~View2DScene();
+	~View2DScene() override;
 public:
 	void init(const Game& game);
 
@@ -67,7 +67,7 @@ public:
 
 	inline int maxValue() const { return m_game.order(); }
 
-public slots:
+public Q_SLOTS:
 	void selectValue(int val);
 	void enterValue(int val, int cell=-1);
 	void markValue(int val, int cell=-1, bool set=true);
@@ -83,7 +83,7 @@ public slots:
 	 *                     Value 0: invalid.
 	 */
 	void updateCage (int cageNumP1, bool drawLabel);
-signals:
+Q_SIGNALS:
 	void valueSelected(int val);
 protected:
 	void wheelEvent(QGraphicsSceneWheelEvent* event) override;
@@ -107,14 +107,14 @@ class View2D : public QGraphicsView, public ViewInterface {
 	Q_OBJECT
 public:
 	View2D(QWidget* parent, const Game& game, GameActions* gameActions);
-	~View2D();
+	~View2D() override;
 
 public:
 	QWidget* widget() override { return this; }
-public slots:
+public Q_SLOTS:
 	void selectValue(int value) override;
 	void settingsChanged();
-signals:
+Q_SIGNALS:
 	void valueSelected(int value);
 protected:
 	void resizeEvent(QResizeEvent* e) override;
